##  Linking Beyond Suggested Fact Sheets
To link an item to a fact sheet that’s different from the one that the systems suggests, do the following:
  1. Choose a discovered item.
  2. Under Discovered Fact Sheets in the side panel, hover over a suggested fact sheet and choose Edit.
  3. Search for and select the desired fact sheet.
  4. Choose Add to Inventory to establish the link.
